==> jackrabbit-oak-1.50.0-src.zip: jackrabbit-oak-1.50.0/oak-doc/src/site/markdown/roadmap.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Roadmap
=======

Release Model
-------------
Following the release of Oak 1.10 we have started to make (even-numbered) stable
releases directly from [trunk](https://github.com/apache/jackrabbit-oak/tree/trunk/):

* [download](https://jackrabbit.apache.org/jcr/downloads.html#latest)

Starting with 1.48.0, these require Java 11.

Maintenance branches
--------------------
We currently support the following maintenance branches:

* [Oak 1.22](https://github.com/apache/jackrabbit-oak/tree/1.22/) ([download](https://jackrabbit.apache.org/jcr/downloads.html#oak1.22)) - from Java 8 up to Java 13
* [Oak 1.8](https://github.com/apache/jackrabbit-oak/tree/1.8/) ([download](https://jackrabbit.apache.org/jcr/downloads.html#oak1.8)) - from Java 8 up to Java 13 - "end of life" planned for Spring 2023

End of life
-----------
The following branches have reached "end of life":

* [Oak 1.10](https://github.com/apache/jackrabbit-oak/tree/1.10/)
* [Oak 1.6](https://github.com/apache/jackrabbit-oak/tree/1.6/)
* [Oak 1.4](https://github.com/apache/jackrabbit-oak/tree/1.4/)
* [Oak 1.2](https://github.com/apache/jackrabbit-oak/tree/1.2/)
* [Oak 1.0](https://github.com/apache/jackrabbit-oak/tree/1.0/)

==> jackrabbit-oak-1.58.0-src.zip: jackrabbit-oak-1.58.0/oak-doc/src/site/markdown/roadmap.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Roadmap
=======

Release Model
-------------
Following the release of Oak 1.10 we have started to make (even-numbered) stable
releases directly from [trunk](https://github.com/apache/jackrabbit-oak/tree/trunk/):

* [download](https://jackrabbit.apache.org/jcr/downloads.html#latest)

Starting with 1.50.0, these require Java 11.

Maintenance branches
--------------------
We currently support one maintenance branch:

* [Oak 1.22](https://github.com/apache/jackrabbit-oak/tree/1.22/) ([download](https://jackrabbit.apache.org/jcr/downloads.html#oak1.22)) - from Java 8 up to Java 13

End of life
-----------
The following branches have reached "end of life":

* [Oak 1.10](https://github.com/apache/jackrabbit-oak/tree/1.10/)
* [Oak 1.8](https://github.com/apache/jackrabbit-oak/tree/1.8/)
* [Oak 1.6](https://github.com/apache/jackrabbit-oak/tree/1.6/)
* [Oak 1.4](https://github.com/apache/jackrabbit-oak/tree/1.4/)
* [Oak 1.2](https://github.com/apache/jackrabbit-oak/tree/1.2/)
* [Oak 1.0](https://github.com/apache/jackrabbit-oak/tree/1.0/)
